@@ -1085,7 +1085,7 @@ where
                                     span: DUMMY_SP,
                                     value: 0.0,
                                 })));
-                                tracing::trace!("injecting zero to preserve `this` in call");
+                                tracing::debug!("injecting zero to preserve `this` in call");
 
                                 *b_callee = Box::new(Expr::Seq(SeqExpr {
                                     span: b_callee.span(),
